Index: /main/waeup.ikoba/trunk/src/waeup/ikoba/customers/browser.py
===================================================================
--- /main/waeup.ikoba/trunk/src/waeup/ikoba/customers/browser.py	(revision 12055)
+++ /main/waeup.ikoba/trunk/src/waeup/ikoba/customers/browser.py	(revision 12056)
@@ -975,5 +975,5 @@
             tableheader.append([(Id, 'document_id', 2),
                              (Title, 'title', 6),
-                             (Type, 'translated_classname', 6),
+                             (Type, 'translated_class_name', 6),
                              (State, 'translated_state', 2),
                              (LT, 'formatted_transition_date', 3),
Index: /main/waeup.ikoba/trunk/src/waeup/ikoba/customers/browser_templates/documentpage.pt
===================================================================
--- /main/waeup.ikoba/trunk/src/waeup/ikoba/customers/browser_templates/documentpage.pt	(revision 12055)
+++ /main/waeup.ikoba/trunk/src/waeup/ikoba/customers/browser_templates/documentpage.pt	(revision 12056)
@@ -13,4 +13,12 @@
   tal:define="files provider:files">
   <tbody>
+    <tr>
+      <td i18n:translate="" class="fieldname">
+        Document Type:
+      </td>
+      <td>
+        <span tal:content="context/translated_class_name">CLASSNAME</span>
+      </td>
+    </tr>
     <tal:widgets content="structure provider:widgets" />
     <tr tal:condition="python: files.replace('\n','')">
Index: /main/waeup.ikoba/trunk/src/waeup/ikoba/customers/browser_templates/documentsmanagepage.pt
===================================================================
--- /main/waeup.ikoba/trunk/src/waeup/ikoba/customers/browser_templates/documentsmanagepage.pt	(revision 12055)
+++ /main/waeup.ikoba/trunk/src/waeup/ikoba/customers/browser_templates/documentsmanagepage.pt	(revision 12056)
@@ -29,5 +29,5 @@
         </td>
         <td>
-          <span tal:content="cl/translated_classname">CLASSNAME</span>
+          <span tal:content="cl/translated_class_name">CLASSNAME</span>
         </td>
         <td>
Index: /main/waeup.ikoba/trunk/src/waeup/ikoba/customers/documents.py
===================================================================
--- /main/waeup.ikoba/trunk/src/waeup/ikoba/customers/documents.py	(revision 12055)
+++ /main/waeup.ikoba/trunk/src/waeup/ikoba/customers/documents.py	(revision 12056)
@@ -95,8 +95,8 @@
 
     @property
-    def translated_classname(self):
+    def translated_class_name(self):
         try:
             DOCTYPES_DICT = getUtility(ICustomersUtils).DOCTYPES_DICT
-            return DOCTYPES_DICT[self.classname]
+            return DOCTYPES_DICT[self.class_name]
         except KeyError:
             return
Index: /main/waeup.ikoba/trunk/src/waeup/ikoba/customers/export.py
===================================================================
--- /main/waeup.ikoba/trunk/src/waeup/ikoba/customers/export.py	(revision 12055)
+++ /main/waeup.ikoba/trunk/src/waeup/ikoba/customers/export.py	(revision 12056)
@@ -150,5 +150,5 @@
                   'translated_state',
                   'formatted_transition_date',
-                  'translated_classname']))) + (
+                  'translated_class_name']))) + (
             'customer_id',)
 
Index: /main/waeup.ikoba/trunk/src/waeup/ikoba/customers/interfaces.py
===================================================================
--- /main/waeup.ikoba/trunk/src/waeup/ikoba/customers/interfaces.py	(revision 12055)
+++ /main/waeup.ikoba/trunk/src/waeup/ikoba/customers/interfaces.py	(revision 12056)
@@ -270,5 +270,5 @@
 
     is_editable = Attribute('Document editable by customer')
-    translated_classname = Attribute('Translatable classname')
+    translated_class_name = Attribute('Translatable class name')
 
 
Index: /main/waeup.ikoba/trunk/src/waeup/ikoba/customers/tests/sample_document_data.csv
===================================================================
--- /main/waeup.ikoba/trunk/src/waeup/ikoba/customers/tests/sample_document_data.csv	(revision 12055)
+++ /main/waeup.ikoba/trunk/src/waeup/ikoba/customers/tests/sample_document_data.csv	(revision 12056)
@@ -1,3 +1,3 @@
-classname,document_id,reg_number,title
+class_name,document_id,reg_number,title
 CustomerDocument,d3,1,My first doc
 CustomerDocument,d4,2,My second doc
Index: /main/waeup.ikoba/trunk/src/waeup/ikoba/customers/tests/test_batching.py
===================================================================
--- /main/waeup.ikoba/trunk/src/waeup/ikoba/customers/tests/test_batching.py	(revision 12055)
+++ /main/waeup.ikoba/trunk/src/waeup/ikoba/customers/tests/test_batching.py	(revision 12056)
@@ -318,16 +318,16 @@
     def test_checkConversion(self):
         errs, inv_errs, conv_dict = self.processor.checkConversion(
-            dict(document_id='d1266236341955', classname='CustomerDocument'))
+            dict(document_id='d1266236341955', class_name='CustomerDocument'))
         self.assertEqual(len(errs),0)
         errs, inv_errs, conv_dict = self.processor.checkConversion(
-            dict(document_id='nonsense', classname='CustomerDocument'))
+            dict(document_id='nonsense', class_name='CustomerDocument'))
         self.assertEqual(len(errs),1)
         timestamp = ("%d" % int(time()*10000))[1:]
         document_id = "d%s" % timestamp
         errs, inv_errs, conv_dict = self.processor.checkConversion(
-            dict(document_id=document_id, classname='CustomerDocument'))
+            dict(document_id=document_id, class_name='CustomerDocument'))
         self.assertEqual(len(errs),0)
         errs, inv_errs, conv_dict = self.processor.checkConversion(
-            dict(document_id=document_id, classname='WrongDocument'))
+            dict(document_id=document_id, class_name='WrongDocument'))
         self.assertEqual(len(errs),1)
 
@@ -339,5 +339,5 @@
         fail_file = open(fail_file).read()
         self.assertEqual(fail_file,
-            'classname,reg_number,document_id,title,--ERRORS--\r\n'
+            'class_name,reg_number,document_id,title,--ERRORS--\r\n'
             'CustomerDocument,2,d5,My stolen doc,document_id: id exists\r\n')
         document = self.processor.getEntry(dict(reg_number='1',
Index: /main/waeup.ikoba/trunk/src/waeup/ikoba/customers/tests/test_document.py
===================================================================
--- /main/waeup.ikoba/trunk/src/waeup/ikoba/customers/tests/test_document.py	(revision 12055)
+++ /main/waeup.ikoba/trunk/src/waeup/ikoba/customers/tests/test_document.py	(revision 12056)
@@ -61,5 +61,5 @@
         self.assertEqual(container[id], document)
         self.assertRaises(TypeError, container.addDocument, object())
-        self.assertEqual(document.classname, 'CustomerDocument')
+        self.assertEqual(document.class_name, 'CustomerDocument')
         return
 
Index: /main/waeup.ikoba/trunk/src/waeup/ikoba/customers/tests/test_export.py
===================================================================
--- /main/waeup.ikoba/trunk/src/waeup/ikoba/customers/tests/test_export.py	(revision 12055)
+++ /main/waeup.ikoba/trunk/src/waeup/ikoba/customers/tests/test_export.py	(revision 12056)
@@ -138,5 +138,5 @@
         self.assertEqual(
             result,
-            'classname,document_id,history,last_transition_date,state,title,customer_id\r\n'
+            'class_name,document_id,history,last_transition_date,state,title,customer_id\r\n'
             'CustomerDocument,d101,[],,,,\r\n'
             )
@@ -152,5 +152,5 @@
         result = open(self.outfile, 'rb').read()
         self.assertTrue(
-            'classname,document_id,history,last_transition_date,state,title,customer_id\r\n'
+            'class_name,document_id,history,last_transition_date,state,title,customer_id\r\n'
             in result
             )
@@ -171,5 +171,5 @@
         result = open(self.outfile, 'rb').read()
         self.assertTrue(
-            'classname,document_id,history,last_transition_date,state,title,customer_id\r\n'
+            'class_name,document_id,history,last_transition_date,state,title,customer_id\r\n'
             in result)
         self.assertMatches(
@@ -189,5 +189,5 @@
         result = open(self.outfile, 'rb').read()
         self.assertTrue(
-            'classname,document_id,history,last_transition_date,state,title,customer_id\r\n'
+            'class_name,document_id,history,last_transition_date,state,title,customer_id\r\n'
             in result)
         self.assertMatches(
Index: /main/waeup.ikoba/trunk/src/waeup/ikoba/documents/document.py
===================================================================
--- /main/waeup.ikoba/trunk/src/waeup/ikoba/documents/document.py	(revision 12055)
+++ /main/waeup.ikoba/trunk/src/waeup/ikoba/documents/document.py	(revision 12056)
@@ -81,5 +81,5 @@
 
     @property
-    def classname(self):
+    def class_name(self):
         return self.__class__.__name__
 
Index: /main/waeup.ikoba/trunk/src/waeup/ikoba/documents/interfaces.py
===================================================================
--- /main/waeup.ikoba/trunk/src/waeup/ikoba/documents/interfaces.py	(revision 12055)
+++ /main/waeup.ikoba/trunk/src/waeup/ikoba/documents/interfaces.py	(revision 12056)
@@ -49,5 +49,5 @@
     translated_state = Attribute(
         'Returns a translated, more verbose verification state of a document')
-    classname = Attribute('Name of the document class')
+    class_name = Attribute('Name of the document class')
     formatted_transition_date = Attribute('Last transition formatted date string')
 

Index: /main/waeup.ikoba/trunk/src/waeup/ikoba/customers/batching.py
===================================================================
--- /main/waeup.ikoba/trunk/src/waeup/ikoba/customers/batching.py	(revision 12055)
+++ /main/waeup.ikoba/trunk/src/waeup/ikoba/customers/batching.py	(revision 12056)
@@ -379,6 +379,6 @@
 
     location_fields = []
-    additional_fields = ['document_id', 'classname']
-    additional_headers = ['classname']
+    additional_fields = ['document_id', 'class_name']
+    additional_headers = ['class_name']
 
     def checkHeaders(self, headerfields, mode='ignore'):
@@ -437,10 +437,10 @@
         errs, inv_errs, conv_dict = super(
             CustomerDocumentProcessor, self).checkConversion(row, mode=mode)
         # We need to check if the classname corresponds with the
         # processor chosen. This is to avoid accidentally wrong imports.
         if mode != 'remove':
-            classname = row.get('classname', None)
-            if classname != self.factory_name.strip('waeup.'):
-                errs.append(('classname','wrong processor'))
+            class_name = row.get('class_name', None)
+            if class_name != self.factory_name.strip('waeup.'):
+                errs.append(('class_name','wrong processor'))
         # We have to check document_id.
         document_id = row.get('document_id', None)
@@ -437,10 +437,10 @@
         errs, inv_errs, conv_dict = super(
             CustomerDocumentProcessor, self).checkConversion(row, mode=mode)
-        # We need to check if the classname corresponds with the
+        # We need to check if the class_name corresponds with the
         # processor chosen. This is to avoid accidentally wrong imports.
         if mode != 'remove':